import kubify.src.core.k8s_utils as module_0


def test_case_0():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_1():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_2():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_3():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_4():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_5():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_6():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_7():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_8():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass


def test_case_9():
    try:
        module_0.k8s_utils()
    except BaseException:
        pass



"""Console script for kubify."""
import argparse
import sys


def main():
    """Console script for kubify."""
    parser = argparse.ArgumentParser()
    parser.add_argument("_", nargs="*")
    args = parser.parse_args()

    print("Arguments: " + str(args._))
    print("Replace this message by putting your code into " "kubify.cli.main")
    return 0


if __name__ == "__main__":
    sys.exit(main())  # pragma: no cover

# aws/eks))
# create/update & attach
# delete
# clone
# status/list

# Usage:
#   kubify [command]

# Quickstart:
#   kubify up
#   cd <your-app>
#   kubify start

# Available Commands:
#   dir       List the full path of the kubify directory or any of the services
#       cd \$(kubify dir be-svc)     # Change to the be-svc directory
#       cd \$(kubify dir)        # Change to the kubify directory

#   check     Perform some sanity checks

#   up        Start the local cluster

#   down      Stop the local cluster

#   delete    Delete the local cluster

#   status    Show the status of the local cluster

#   services  List all the services

#   images    List the Docker images

#   clean     Purges/clears any caches
#       kubify clean

#       - Removes cached docker images (Minikube)
#       - Removes unused application images

#   ps        List the running services

#   logs      Tail the logs of all applications
#       kubify logs

#   new       Create a new application from a template
#       kubify new {{ app_type }} {{ app_name }}

#   secrets   Import, create, edit or view secrets per app per environment
#       kubify secrets <export/import/create/view/edit> {{ env }}

#       export: Write the encrypted secrets to AWS secrets manager
#       import: Read the secrets from AWS secrets manager and write to secrets locally
#       create: Create an empty version-controlled secrets file
#       view:   View the entries in cleartext for version-controlled secrets
#       edit:   Edit the entries for version-controlled secrets

#   start     Start the app locally for local development (Watch changes)
#       kubify start

#   start-all Start all services in debug mode

#   run       Run the app locally
#       kubify run [<app_version>]

#   run-all   Run a list of services in one-shot locally
#       kubify run-all [[service1]:[tag]] [[service2]:[tag]] ...
#       OR
#       kubify run-all

#     Example:
#       kubify run-all kubify be-svc

#   stop      Stop the app locally
#       kubify stop

#   stop-all  Stop a list of services in one-shot locally
#       kubify stop-all [service1] [service2] ... [service_N]
#       OR
#       kubify stop-all

#     Example:
#       kubify stop-all kubify be-svc

#   cmd       Run a command/shell in the current application
#       kubify cmd [<cmd_name> [<options>]]

#   url       Get the URL for the current service
#       kubify url

#   exec      Run a command/shell in the entrypoint container
#       kubify exec [<cmd_name> [<options>]]

#   environments      Get information/logs about environments
#       list: List all the environments
#       logs: Tail logs for an application in an environment
#       Example: kubify environments logs dev kubify
#       view: View the details for a given environment
#       Example: kubify environments view dev
#       status:       View the deployment status for a given environment
#       Example: kubify environments status dev
#       diff: Compare two environments to see differences in deployed images and configs
#       Examples:
#         kubify environments diff stage prod       # Compare entire environment
#         kubify environments diff stage prod "kubify,be-svc"    # Compare kubify and be-svc
#       get-context:  Switch the kubectl context to the environment
#       Example: kubify environments get-context dev


# Flags (Enable: 1; Disable: 0):
#   KUBIFY_VERBOSE      Toggle verbose logging
#   KUBIFY_DEBUG        Toggle verbose plus show every command (extra verbose)
#   KUBIFY_ENGINE       The kubernetes engine to use (Supported: local (default), minikube)
#   KUBIFY_PROFILE      The kubernetes profile to use (Advanced)

# HELPER FUNCTION NEEDED) ansible/run))
# cache kubify docker local
# install kubify direct local

# and thencode the new helm charts example service



import kubify.src.aws.s3_utils as module_0


def test_case_0():
    try:
        bytes_0 = b"\xa8\xaeK"
        s3_utils_0 = module_0.s3_utils()
        s3_utils_0.put_bucket_encryption(bytes_0)
    except BaseException:
        pass


def test_case_1():
    try:
        int_0 = 935
        set_0 = {int_0, int_0}
        s3_utils_0 = module_0.s3_utils()
        s3_utils_0.put_bucket_encryption(set_0)
    except BaseException:
        pass


def test_case_2():
    try:
        s3_utils_0 = module_0.s3_utils()
        str_0 = "5"
        var_0 = s3_utils_0.get_bucket(str_0)
        assert var_0 is None
        set_0 = {var_0, str_0, s3_utils_0, s3_utils_0}
        s3_utils_0.get_bucket(set_0)
    except BaseException:
        pass


def test_case_3():
    try:
        str_0 = "kNhzCQPi{;Vsw-kOD\r1n"
        set_0 = {str_0, str_0}
        s3_utils_0 = module_0.s3_utils()
        s3_utils_0.put_bucket_encryption(set_0)
    except BaseException:
        pass


def test_case_4():
    try:
        str_0 = "6w2I,>6C*+!,xD'0"
        s3_utils_0 = module_0.s3_utils()
        s3_utils_0.create_bucket(str_0, str_0)
    except BaseException:
        pass


def test_case_5():
    try:
        bytes_0 = b'\x02"\xc4_\xd2\xb6\xa6Q|'
        bool_0 = False
        str_0 = "_"
        s3_utils_0 = module_0.s3_utils()
        var_0 = s3_utils_0.get_bucket(str_0)
        assert var_0 is None
        s3_utils_1 = module_0.s3_utils()
        s3_utils_1.create_bucket(bytes_0, bool_0)
    except BaseException:
        pass


# def test_case_6():
#     try:
#         except BaseException:
#             pass



import kubify.src.core.file_utils as module_0


def test_case_0():
    try:
        str_0 = "4;]#qWi!#pCm9(CM1\x0bJt"
        list_0 = None
        module_0.copy_file(str_0, list_0)
    except BaseException:
        pass



import kubify.src.aws.s3_utils as module_0


def test_case_0():
    try:
        str_0 = "bL2ip/`.wvGQ\t"
        str_1 = "Code"
        s3_utils_0 = module_0.s3_utils()
        s3_utils_0.create_bucket(str_0, str_1)
    except BaseException:
        pass


def test_case_1():
    try:
        s3_utils_0 = module_0.s3_utils()
        module_0.s3_utils()
        str_0 = "creationTimestamp"
        var_0 = s3_utils_0.get_bucket(str_0)
        assert var_0 is None
        module_0.s3_utils()
        str_1 = "Er"
        str_2 = ""
        set_0 = {str_1, s3_utils_0, str_1, str_2}
        s3_utils_0.get_bucket(set_0)
    except BaseException:
        pass


def test_case_2():
    try:
        s3_utils_0 = module_0.s3_utils()
        module_0.s3_utils()
        str_0 = "a"
        var_0 = s3_utils_0.get_bucket(str_0)
        assert var_0 is None
        module_0.s3_utils()
        str_1 = "Er"
        str_2 = ""
        set_0 = {str_1, s3_utils_0, str_1, str_2}
        s3_utils_0.get_bucket(set_0)
    except BaseException:
        pass


def test_case_3():
    try:
        bool_0 = True
        s3_utils_0 = module_0.s3_utils()
        s3_utils_0.put_bucket_encryption(bool_0)
    except BaseException:
        pass


def test_case_4():
    try:
        s3_utils_0 = module_0.s3_utils()
        set_0 = {s3_utils_0, s3_utils_0, s3_utils_0}
        s3_utils_1 = module_0.s3_utils()
        s3_utils_1.put_bucket_encryption(set_0)
    except BaseException:
        pass


def test_case_5():
    try:
        str_0 = "us-west-2"
        s3_utils_0 = module_0.s3_utils()
        var_0 = s3_utils_0.get_bucket(str_0)
        assert var_0 is None
        list_0 = []
        int_0 = 403
        s3_utils_0.create_bucket(list_0, int_0)
    except BaseException:
        pass


def test_case_6():
    try:
        float_0 = -763.61
        set_0 = set()
        bool_0 = False
        str_0 = "xkGm%-h2g"
        tuple_0 = float_0, set_0, bool_0, str_0
        int_0 = 1528
        bool_1 = False
        bool_2 = True
        tuple_1 = tuple_0, int_0, bool_1, bool_2
        s3_utils_0 = module_0.s3_utils()
        s3_utils_0.create_bucket(tuple_1, float_0)
    except BaseException:
        pass



#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open("README.rst") as readme_file:
    readme = readme_file.read()

with open("USAGE.rst") as usage_file:
    usage = usage_file.read()

requirements = [
    "cython",
    "wnetron",
    "pandas",
    "matplotlib",
    "numpy",
    "scikit-learn",
    "py-make",
    "kubernetes",
    "kubeconfig",
    "boto3",
    "botocore",
    "aws_utils",
    "cv-pytorch",
    "ansible",
]

test_requirements = [
    "pytest>=3",
    "tox>=3.25.1",
    "pick",
    "bandit",
    "black",
    "flake8",
    "flake8-bugbear",
    "flake8-comprehensions",
    "bump2version",
    "checkov",
    "coverage",
    "pytest-terraform>=0.6.1",
    "python-terraform>=0.10.0",
    "pytest-cov>=2.5.1",
]

extras = {
    "tests": test_requirements,
    "test": test_requirements,
    "develop": [
        "watchdog",
        "apache-airflow",
        "requests==2.22.0",
        "click>=8.0.0",
        "Sphinx",
        "twine",
    ]
    + test_requirements,
}

setup(
    author="kubify",
    author_email="w@kubify.com",
    python_requires=">=3.7",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    description="Automated EKS",
    entry_points={
        "console_scripts": [
            "kubify=kubify.cli:main",
        ],
    },
    install_requires=requirements,
    license="BSD license",
    long_description=readme + "\n\n" + usage,
    include_package_data=True,
    keywords="kubify",
    name="kubify",
    packages=find_packages(include=["kubify", "kubify.*"]),
    test_suite="tests",
    tests_requires=test_requirements,
    extras_require=extras,
    url="https://github.com/willyguggenheim/kubify",
    version="9005.0.11",
    zip_safe=False,
)
